@@ -2521,6 +2521,7 @@ def ClassifyBehaviorMultiVideos(data, bodyparts_list, dimensions = 2,distance=28
 
     import numpy as np
     import pandas as pd
+    import pyratlib as rat
     from sklearn.preprocessing import StandardScaler
 
     n_jobs = kwargs.get('n_jobs')
@@ -2542,16 +2543,16 @@ def ClassifyBehaviorMultiVideos(data, bodyparts_list, dimensions = 2,distance=28
     cluster_labels   = {}
     distance_df      = {}
 
-    model,embedding  = model_distance(dimensions = dimensions,
-                                      distance=distance,
-                                      n_jobs=n_jobs,
-                                      verbose=verbose, 
-                                      perplexity=perplexity,
-                                      learning_rate=learning_rate)
+    model,embedding  = rat.model_distance(dimensions = dimensions,
+                                          distance=distance,
+                                          n_jobs=n_jobs,
+                                          verbose=verbose, 
+                                          perplexity=perplexity,
+                                          learning_rate=learning_rate)
 
 
     for i,video in enumerate(data):
-        dist_temp            = np.asarray(distance_metrics(data[video],
+        dist_temp            = np.asarray(rat.distance_metrics(data[video],
                                           bodyparts_list=bodyparts_list,
                                           distance=distance))    
         distancias[video]    = dist_temp
